Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1060)

Unified Diff: third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h

Issue 2695603002: Replace OffscreenCanvasSurfaceClient with DisplayCompositorClient (Closed)
Patch Set: Delete unused import surface_info Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h
diff --git a/third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h b/third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h
index ce5051281f2986e70d71f1e75f78c7aa7b52a651..86b2b363cf093bcccb6572f469aed38a4e4573ec 100644
--- a/third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h
+++ b/third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h
@@ -5,14 +5,15 @@
#ifndef CanvasSurfaceLayerBridge_h
#define CanvasSurfaceLayerBridge_h
+#include <memory>
#include "base/memory/ref_counted.h"
#include "base/memory/weak_ptr.h"
+#include "cc/ipc/display_compositor.mojom-blink.h"
#include "cc/surfaces/surface_id.h"
#include "cc/surfaces/surface_reference_factory.h"
#include "mojo/public/cpp/bindings/binding.h"
#include "platform/PlatformExport.h"
#include "public/platform/modules/offscreencanvas/offscreen_canvas_surface.mojom-blink.h"
-#include <memory>
namespace cc {
class Layer;
@@ -33,7 +34,7 @@ class PLATFORM_EXPORT CanvasSurfaceLayerBridgeObserver {
};
class PLATFORM_EXPORT CanvasSurfaceLayerBridge
- : NON_EXPORTED_BASE(public mojom::blink::OffscreenCanvasSurfaceClient) {
+ : NON_EXPORTED_BASE(public cc::mojom::blink::DisplayCompositorClient) {
public:
explicit CanvasSurfaceLayerBridge(CanvasSurfaceLayerBridgeObserver*,
WebLayerTreeView*);
@@ -42,7 +43,7 @@ class PLATFORM_EXPORT CanvasSurfaceLayerBridge
WebLayer* getWebLayer() const { return m_webLayer.get(); }
const cc::FrameSinkId& getFrameSinkId() const { return m_frameSinkId; }
// Implementation of mojom::blink::OffscreenCanvasSurfaceClient
void OnSurfaceCreated(const cc::SurfaceInfo&) override;
void satisfyCallback(const cc::SurfaceSequence&);
@@ -58,7 +59,7 @@ class PLATFORM_EXPORT CanvasSurfaceLayerBridge
CanvasSurfaceLayerBridgeObserver* m_observer;
mojom::blink::OffscreenCanvasSurfacePtr m_service;
- mojo::Binding<mojom::blink::OffscreenCanvasSurfaceClient> m_binding;
+ mojo::Binding<cc::mojom::blink::DisplayCompositorClient> m_binding;
const cc::FrameSinkId m_frameSinkId;
cc::SurfaceId m_currentSurfaceId;
« no previous file with comments | « services/ui/ws/BUILD.gn ('k') | third_party/WebKit/public/platform/modules/offscreencanvas/offscreen_canvas_surface.mojom » ('j') | no next file with comments »
@@ -42,7 +43,7 @@ class PLATFORM_EXPORT CanvasSurfaceLayerBridge
WebLayer* getWebLayer() const { return m_webLayer.get(); }
const cc::FrameSinkId& getFrameSinkId() const { return m_frameSinkId; }
- // Implementation of mojom::blink::OffscreenCanvasSurfaceClient
+ // Implementation of cc::mojom::blink::DisplayCompositorClient
void OnSurfaceCreated(const cc::SurfaceInfo&) override;
void satisfyCallback(const cc::SurfaceSequence&);

Powered by Google App Engine
This is Rietveld 408576698